import {CommonUtil} from "oly-core";
import {LocalFileOptions} from "./interfaces";
import {exists, readFile, remove, rename, writeFile} from "fs-promise";
import {WorkspaceProvider} from "./WorkspaceProvider";

export class LocalFile {

  constructor(private workspaceProvider: WorkspaceProvider,
              private options: LocalFileOptions) {
    this.options.name = this.options.name || CommonUtil.shortid();
    this.options.encoding = this.options.encoding || 'UTF-8';
  }

  get path() {
    return this.workspaceProvider.directory + '/' + this.options.name;
  }

  async exists(): Promise<boolean> {
    return await exists(this.path);
  }

  async read(): Promise<string> {
    return await readFile(this.path, this.options.encoding);
  }

  async write(data: string) {
    await writeFile(this.path, data);
  }

  async swap(file: LocalFile) {
    await file.remove();
    await this.rename(file.options.name);
  }

  async rename(name: string) {
    const oldPath = this.path;
    this.options.name = name;
    await rename(oldPath, this.path);
  }

  async remove() {
    await remove(this.path);
  }
}
