import {env} from "oly-core";
import {mkdirp, remove} from "fs-promise";
import {join} from "path";

export class WorkspaceProvider {

  @env('WORKSPACE_DIRECTORY')
  public directory: string = join(process.cwd(), 'workspace');

  @env('WORKSPACE_DIRECTORY_JUNK')
  public junk: string = '.junk';

  protected async onStart(): Promise<void> {
    await mkdirp(this.directory);
    await remove(this.join(this.junk));
    await mkdirp(this.join(this.junk));
  }

  protected async onStop(): Promise<void> {
    await remove(this.join(this.junk));
  }

  /**
   * Generate a filepath. Useful for temp file or test.
   *
   * @return Random filepath
   */
  randomTmpPath(): string {
    return this.join(this.junk, Math.random().toString(36).substr(2, 9));
  }

  /**
   * Get absolute path of workspace file.
   *
   * @param entry
   * @return {string}
   */
  join(...entry: string[]): string {
    return join(this.directory, ...entry);
  }

  /**
   * Destroy a file.
   *
   * @param path    File path to kill
   * @return        Nothing when process is done
   */
  async rm(path): Promise<void> {
    await remove(this.join(path));
  }

}
